%     Copyright (C) 2023 Jordi Llopis-Lorente. Contact: jorllolo@etsii.upv.es
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function [CTDxx, cai_syst, cai_diast, RAsCa, alternansCa]=CTD_beats(time,X, xx, flag)  
%%%% CTDxx: Ca2+ transient duration at xx% of the initial base value (xx, eg.90%)
%%%% cai_syst: systolic calcium concentration (uM)
%%%% cai_diast: diastolic calcium concentration (uM)
%%%% RAsCa: repolarization abormanilities in tha calcium transient
%%%% alternansCa: alternans in the calcium transient
%%%% t:time vector
%%%% X: output from modelRunner_drugs
%%%% xx: % of the initial base value to calculate the transient durantion
%%%% (eg. 90)
%%%% flag indicates if an EAD has been detected previously


 CTDxx = zeros(size(X,1),1);
 cai_syst = zeros(size(X,1),1);
 cai_diast = zeros(size(X,1),1);
 RAsCa = zeros(size(X,1),1);
 alternansCa = zeros(size(X,1),1);

for i = 1:size(X, 1)
    t=time{i,1};
    cai = X{i,1}(:,6)*10^3;
    [CTDxx(i),cai_syst(i),cai_diast(i),RAsCa(i)]=CTD(t,cai,xx, flag(i));
end

if sum(diff(CTDxx)>=5)>=1 || sum(flag)>=1
    alternansCa = CTDxx;
end

CTDxx = mean(CTDxx);
cai_syst = mean(cai_syst);
cai_diast = mean(cai_diast);

end

function [CTDxx,cai_syst,cai_diast, EAD]=CTD(t,cai,xx, flag)  
[cai_syst, cai_sys_index]=max(cai);
t_ind_rep=find(t>300,1);
[cai_diast, cai_diast_index]=min(cai(t_ind_rep:end));

dCaidt=diff(cai)./diff(t);

% detectar EADs
if sum(dCaidt(t_ind_rep:end)>0.0001)>1 | flag == 1
    CTDxx=NaN;
    cai_syst=NaN;
    cai_diast=NaN;
    EAD = 1;
else
    Acai=cai_syst-cai_diast;
    cat_xxrec=cai_syst-(xx/100)*Acai;
    t_catxx = interp1(cai(cai_sys_index:end),t(cai_sys_index:end),cat_xxrec);
    [~,ind]=max(dCaidt);
    CTDxx=t_catxx-t(ind);
    EAD = 0;
end
end
