%     Copyright (C) 2023 Jordi Llopis-Lorente. Contact: jorllolo@etsii.upv.es
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function [ drug_effect ] = calculateDrug_effect(D, IC50)
% Returns a vector with the non-block fraction for each channel
% (drug_effect). It contaings non-block fractions for the following
% challens: [INa INaL ICaL IKr]
% D is the drug concentration
% IC50 is a vector containing the IC50 values and the hill coefficients for
% the different currents. It should be: [ICKr hKr ICNa hNa ICNaL hNaL ICCaL
% hCaL]
%%
    ICNa=IC50(3); 
    hNa=IC50(4);
    ICNaL=IC50(5);  
    hNaL=IC50(6); 
    ICCaL=IC50(7);  
    hCaL=IC50(8);  
    ICKr=IC50(1);  
    hKr=IC50(2); 
%%
if isnan(ICNa)&& isnan(hNa)
    drug_effect(1)=0;
else
    drug_effect(1)=1/(1+(D/ICNa)^hNa);
end

if isnan(ICNaL)&& isnan(hNaL)
    drug_effect(2)=0;
else
    drug_effect(2)=1/(1+(D/ICNaL)^hNaL);
end

if isnan(ICCaL)&& isnan(hCaL)
    drug_effect(3)=0;
else
    drug_effect(3)=1/(1+(D/ICCaL)^hCaL);
end

if isnan(ICKr)&& isnan(hKr)
    drug_effect(4)=0;
else
    drug_effect(4)=1/(1+(D/ICKr)^hKr);
end

end

